# TokenIntrospectOptions

Set of options controling how the token is introspected
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**exclude_roles** | **bool** | Parameter controlling whether to determine the roles during introspection | [optional] [default to False]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


